# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.

from ._version import __version__
from .handlers import add_handlers, LabHandler
from .app import LabLauncherApp
